pub enum HttpWebhook {
SetWebhook(MethodCall),
SetWebhookTimeout(Elapsed),
Server(Error),
}Expand description
Represents possible errors that a webhook server may return.
Variants
SetWebhook(MethodCall)
An error while setting the webhook.
SetWebhookTimeout(Elapsed)
Calling the setWebhook method timed out.
Server(Error)
An error while running the server.
Implementations
Sourceimpl HttpWebhook
impl HttpWebhook
Sourcepub fn is_set_webhook(&self) -> bool
pub fn is_set_webhook(&self) -> bool
Returns true if self is of variant SetWebhook.
Sourcepub fn expect_set_webhook(self) -> MethodCallwhere
Self: Debug,
pub fn expect_set_webhook(self) -> MethodCallwhere
Self: Debug,
Unwraps the value, yielding the content of SetWebhook.
Panics
Panics if the value is not SetWebhook, with a panic message including the content of self.
Sourcepub fn set_webhook(self) -> Option<MethodCall>
pub fn set_webhook(self) -> Option<MethodCall>
Returns Some if self is of variant SetWebhook, and None otherwise.
Sourcepub fn is_set_webhook_timeout(&self) -> bool
pub fn is_set_webhook_timeout(&self) -> bool
Returns true if self is of variant SetWebhookTimeout.
Sourcepub fn expect_set_webhook_timeout(self) -> Elapsedwhere
Self: Debug,
pub fn expect_set_webhook_timeout(self) -> Elapsedwhere
Self: Debug,
Unwraps the value, yielding the content of SetWebhookTimeout.
Panics
Panics if the value is not SetWebhookTimeout, with a panic message including the content of self.
Sourcepub fn set_webhook_timeout(self) -> Option<Elapsed>
pub fn set_webhook_timeout(self) -> Option<Elapsed>
Returns Some if self is of variant SetWebhookTimeout, and None otherwise.
Sourcepub fn expect_server(self) -> Errorwhere
Self: Debug,
pub fn expect_server(self) -> Errorwhere
Self: Debug,