Formattable

Trait Formattable 

pub trait Formattable { }
Represents a value that can be formatted for MarkdownV2.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Formattable for &str

Source

impl Formattable for String

Source

impl Formattable for bool

Source

impl Formattable for char

Source

impl Formattable for f32

Source

impl Formattable for f64

Source

impl Formattable for i8

Source

impl Formattable for i16

Source

impl Formattable for i32

Source

impl Formattable for i64

Source

impl Formattable for i128

Source

impl Formattable for isize

Source

impl Formattable for u8

Source

impl Formattable for u16

Source

impl Formattable for u32

Source

impl Formattable for u64

Source

impl Formattable for u128

Source

impl Formattable for usize

Source

impl<A, B, C, D, E, F, G, H, I, J, K> Formattable for (A, B, C, D, E, F, G, H, I, J, K)

Source

impl<A, B, C, D, E, F, G, H, I, J> Formattable for (A, B, C, D, E, F, G, H, I, J)

Source

impl<A, B, C, D, E, F, G, H, I> Formattable for (A, B, C, D, E, F, G, H, I)

Source

impl<A, B, C, D, E, F, G, H> Formattable for (A, B, C, D, E, F, G, H)

Source

impl<A, B, C, D, E, F, G> Formattable for (A, B, C, D, E, F, G)

Source

impl<A, B, C, D, E, F> Formattable for (A, B, C, D, E, F)

Source

impl<A, B, C, D, E> Formattable for (A, B, C, D, E)

Source

impl<A, B, C, D> Formattable for (A, B, C, D)

Source

impl<A, B, C> Formattable for (A, B, C)

Source

impl<A, B> Formattable for (A, B)
where A: Formattable, B: Formattable,

Source

impl<T: Formattable + ?Sized> Formattable for Box<T>

Source

impl<T: Formattable> Formattable for &[T]

Source

impl<T: Formattable> Formattable for Vec<T>

Implementors

Source

impl<'a> Formattable for Entity<'a>

Source

impl<'a> Formattable for SemanticEntity<'a>

Source

impl<I, T, L> Formattable for CodeBlock<I, L>
where for<'a> &'a I: IntoIterator<Item = &'a T>, T: Deref<Target = str>, L: Deref<Target = str>,

Source

impl<I, T> Formattable for InlineCode<I>
where for<'a> &'a I: IntoIterator<Item = &'a T>, T: Deref<Target = str>,

Source

impl<I, T> Formattable for Raw<I>
where for<'a> &'a I: IntoIterator<Item = &'a T>, T: Deref<Target = str>,

Source

impl<T, L> Formattable for Link<T, L>
where T: Formattable, L: Deref<Target = str>,

Source

impl<T: Formattable> Formattable for Bold<T>

Source

impl<T: Formattable> Formattable for Italic<T>

Source

impl<T: Formattable> Formattable for MarkdownV2<T>

Source

impl<T: Formattable> Formattable for Strikethrough<T>

Source

impl<T: Formattable> Formattable for Underline<T>