pub trait Formattable: Formattable + Formattable { }Expand description
A value that can be formatted in all markups.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait Formattable: Formattable + Formattable { }A value that can be formatted in all markups.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".