Permissions

Struct Permissions 

#[non_exhaustive]
pub struct Permissions { pub can_send_messages: Option<bool>, pub can_send_media_messages: Option<bool>, pub can_send_polls: Option<bool>, pub can_send_other_messages: Option<bool>, pub can_add_web_page_previews: Option<bool>, pub can_change_info: Option<bool>, pub can_invite_users: Option<bool>, pub can_pin_messages: Option<bool>, }
Describes actions that a non-administrator user is allowed to take in a chat.

This struct is a representation of ChatPermissions.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
can_send_messages: Option<bool>

true if the user can send text messages, contacts, locations and venues.

can_send_media_messages: Option<bool>

true if the user can send audios, documents, photos, videos, video notes and voice notes. Implies can_send_messages.

can_send_polls: Option<bool>

true if the user can send polls. Implies can_send_messages.

can_send_other_messages: Option<bool>

true if the user can use inline bots and send animations, games and stickers. Implies can_send_media_messages.

can_add_web_page_previews: Option<bool>

true if the user can add web page previews. Implies can_send_media_messages.

can_change_info: Option<bool>

true if the user can change the chat information. Ignored in public supergroups.

can_invite_users: Option<bool>

true if the user can invite new users.

can_pin_messages: Option<bool>

true is the user can pin messages. Ignored in public supegroups.

Implementations

Source

impl Permissions

pub fn new() -> Self

Constructs Permissions with all fields set to None.

pub fn can_send_messages(self, can_send: bool) -> Self

Configures if the user can send messages.

pub fn can_send_media_messages(self, can_send: bool) -> Self

Configures if the user can send media messages.

pub fn can_send_polls(self, can_send: bool) -> Self

Configures if the user can send polls.

pub fn can_send_other_messages(self, can_send: bool) -> Self

Configures if the user can send other messages not covered by other permissions.

pub fn can_add_web_page_previews(self, can_add: bool) -> Self

Configures if the user can add webpage previews.

pub fn can_change_info(self, can_change: bool) -> Self

Configures if the user can change chat information.

pub fn can_invite_users(self, can_invite: bool) -> Self

Configures if the user can invite new users to the chat.

pub fn can_pin_messages(self, can_pin: bool) -> Self

Configures if the user can pin messages.