EntityKind

Enum EntityKind 

#[non_exhaustive]
pub enum EntityKind {
Show 15 variants Mention, Hashtag, Cashtag, BotCommand, Url, Email, PhoneNumber, Bold, Italic, Underline, Strikethrough, Code, Pre(Option<String>), TextLink(String), TextMention(User),
}
Represents an entity’s kind.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Mention

A mention.



Hashtag

A hashtag.



Cashtag

A cashtag (e.g. $TBOT).



BotCommand

A bot command.



Url

An url.



Email

An email.



PhoneNumber

A phone number.



Bold

Text in bold.



Italic

Text in italic.



Underline

Underlined text.



Strikethrough

Strikethrough text.



Code

String of monowidth text.



Pre(Option<String>)

Block of monowidth text.

A clickable text url.



TextMention(User)

A mention for users without username.

Implementations

Source

impl EntityKind

pub fn is_mention(&self) -> bool

Returns true if self is of variant Mention.

pub fn is_hashtag(&self) -> bool

Returns true if self is of variant Hashtag.

pub fn is_cashtag(&self) -> bool

Returns true if self is of variant Cashtag.

pub fn is_bot_command(&self) -> bool

Returns true if self is of variant BotCommand.

pub fn is_url(&self) -> bool

Returns true if self is of variant Url.

pub fn is_email(&self) -> bool

Returns true if self is of variant Email.

pub fn is_phone_number(&self) -> bool

Returns true if self is of variant PhoneNumber.

pub fn is_bold(&self) -> bool

Returns true if self is of variant Bold.

pub fn is_italic(&self) -> bool

Returns true if self is of variant Italic.

pub fn is_underline(&self) -> bool

Returns true if self is of variant Underline.

pub fn is_strikethrough(&self) -> bool

Returns true if self is of variant Strikethrough.

pub fn is_code(&self) -> bool

Returns true if self is of variant Code.

pub fn is_pre(&self) -> bool

Returns true if self is of variant Pre.

pub fn expect_pre(self) -> Option<String>
where Self: Debug,

Unwraps the value, yielding the content of Pre.

Panics

Panics if the value is not Pre, with a panic message including the content of self.

pub fn pre(self) -> Option<Option<String>>

Returns Some if self is of variant Pre, and None otherwise.

Returns true if self is of variant TextLink.

Unwraps the value, yielding the content of TextLink.

Panics

Panics if the value is not TextLink, with a panic message including the content of self.

Returns Some if self is of variant TextLink, and None otherwise.

pub fn is_text_mention(&self) -> bool

Returns true if self is of variant TextMention.

pub fn expect_text_mention(self) -> User
where Self: Debug,

Unwraps the value, yielding the content of TextMention.

Panics

Panics if the value is not TextMention, with a panic message including the content of self.

pub fn text_mention(self) -> Option<User>

Returns Some if self is of variant TextMention, and None otherwise.