[−][src]Enum tbot::errors::HttpWebhook
Represents possible errors that a webhook server may return.
Variants
SetWebhook(MethodCall)An error while setting the webhook.
SetWebhookTimeout(Elapsed)Calling the setWebhook method timed out.
Server(Error)An error while running the server.
Implementations
impl HttpWebhook[src]
pub fn is_set_webhook(&self) -> bool[src]
Returns true if self is of variant SetWebhook.
pub fn expect_set_webhook(self) -> MethodCall where
Self: Debug, [src]
Self: Debug,
Unwraps the value, yielding the content of SetWebhook.
Panics
Panics if the value is not SetWebhook, with a panic message including the content of self.
pub fn set_webhook(self) -> Option<MethodCall>[src]
Returns Some if self is of variant SetWebhook, and None otherwise.
pub fn is_set_webhook_timeout(&self) -> bool[src]
Returns true if self is of variant SetWebhookTimeout.
pub fn expect_set_webhook_timeout(self) -> Elapsed where
Self: Debug, [src]
Self: Debug,
Unwraps the value, yielding the content of SetWebhookTimeout.
Panics
Panics if the value is not SetWebhookTimeout, with a panic message including the content of self.
pub fn set_webhook_timeout(self) -> Option<Elapsed>[src]
Returns Some if self is of variant SetWebhookTimeout, and None otherwise.
pub fn is_server(&self) -> bool[src]
Returns true if self is of variant Server.
pub fn expect_server(self) -> Error where
Self: Debug, [src]
Self: Debug,
Unwraps the value, yielding the content of Server.
Panics
Panics if the value is not Server, with a panic message including the content of self.
pub fn server(self) -> Option<Error>[src]
Returns Some if self is of variant Server, and None otherwise.