pub trait Formattable { }Expand description
Represents a value that can be formatted for MarkdownV2.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait Formattable { }Represents a value that can be formatted for MarkdownV2.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".